@@ -9,17 +9,17 @@ from .constants import CONFIG_FILE, PROTONGE_URL
 from .constants import TEMP_DIR, DEFAULT_INSTALL_DIR
 
 
-def fetch_data(tag):
+def fetch_data(tag) -> dict:
     """
     Fetch ProtonGE release information from github
-    Return Type: dict
+    Return Type: dict {str, str}
     Content(s):
         'version', date', 'download', 'size', 'checksum'
     """
     url = PROTONGE_URL + (f'/tags/{tag}' if tag else '/latest')
     data = requests.get(url).json()
     if 'tag_name' not in data:
-        return None  # invalid tag
+        return {}  # invalid tag
 
     values = {'version': data['tag_name'], 'date': data['published_at'].split('T')[0]}
     for asset in data['assets']:
@@ -31,18 +31,19 @@ def fetch_data(tag):
     return values
 
 
-def fetch_releases(count=100):
+def fetch_releases(count=100) -> list:
     """
     List ProtonGE releases on Github
-    Return Type: str[]
+    Return Type: list[str]
     """
     tags = []
     for release in requests.get(PROTONGE_URL + "?per_page=" + str(count)).json():
         tags.append(release['tag_name'])
+    tags.reverse()
     return tags
 
 
-def install_directory(target=None):
+def install_directory(target=None) -> str:
     """
     Custom install directory
     Return Type: str
@@ -69,10 +70,10 @@ def install_directory(target=None):
     return DEFAULT_INSTALL_DIR
 
 
-def installed_versions():
+def installed_versions() -> list:
     """
     List of proton installations
-    Return Type: str[]
+    Return Type: list[str]
     """
     installdir = install_directory()
     versions_found = []
@@ -80,14 +81,12 @@ def installed_versions():
     if os.path.exists(installdir):
         folders = os.listdir(installdir)
         # Find names of directories with proton
-        for folder in folders:
-            if os.path.exists(f'{installdir}/{folder}/proton'):
-                versions_found.append(folder)
+        versions_found = [folder for folder in folders if os.path.exists(installdir + '/' + folder + "/proton")]
 
     return versions_found
 
 
-def get_proton(version=None, yes=True, dl_only=False, output=None):
+def get_proton(version=None, yes=True, dl_only=False, output=None) -> bool:
     """Download and (optionally) install Proton"""
     installdir = install_directory()
     data = fetch_data(tag=version)
@@ -97,7 +96,7 @@ def get_proton(version=None, yes=True, dl_only=False, output=None):
             print('[ERROR] invalid tag / binary not found')
         return False
 
-    protondir = installdir + 'Proton-' + data['version']
+    protondir = installdir + data['version']
     checksum_dir = protondir + '/sha512sum'
     source_checksum = requests.get(data['checksum']).text if 'checksum' in data else None
     local_checksum = open(checksum_dir).read() if os.path.exists(checksum_dir) else None
@@ -107,23 +106,23 @@ def get_proton(version=None, yes=True, dl_only=False, output=None):
         if local_checksum and source_checksum:
             if local_checksum in source_checksum:
                 if not yes:
-                    print(f"[INFO] Proton-{data['version']} already installed")
+                    print(f"[INFO] {data['version']} already installed")
                     print("[INFO] No hotfix found")
-                return
+                return False
             elif not yes:
                 print("[INFO] Hotfix available")
         else:
             if not yes:
-                print(f"[INFO] Proton-{data['version']} already installed")
-            return
+                print(f"[INFO] {data['version']} already installed")
+            return False
 
     # Confirmation
     if not yes:
-        print(f"Ready to download Proton-{data['version']}",
+        print(f"Ready to download {data['version']}",
               f"\nSize      : {readable_size(data['size'])}",
               f"\nPublished : {data['date']}")
         if input("Continue? (Y/n): ") not in ['y', 'Y', '']:
-            return
+            return False
 
     # Prepare Destination
     destination = output if output else (os.getcwd() if dl_only else TEMP_DIR)
@@ -136,14 +135,14 @@ def get_proton(version=None, yes=True, dl_only=False, output=None):
     if not download(url=data['download'], destination=destination, show_progress=not yes):
         if not yes:
             print("[ERROR] Download failed")
-        return
+        return True
 
     download_checksum = sha512sum(destination)
     if source_checksum and (download_checksum not in source_checksum):
         if not yes:
             print("[ERROR] Checksum verification failed")
         shutil.rmtree(TEMP_DIR, ignore_errors=True)
-        return
+        return True
 
     # Installation
     if not dl_only:
@@ -154,17 +153,17 @@ def get_proton(version=None, yes=True, dl_only=False, output=None):
             print('[INFO] Installed in: ' + protondir)
         open(checksum_dir, 'w').write(download_checksum)
     elif not yes:
-        print('[INFO] Dowloaded to: ' + destination)
+        print('[INFO] Downloaded to: ' + destination)
 
     # Clean up
     shutil.rmtree(TEMP_DIR, ignore_errors=True)
 
+    return True
 
-def remove_proton(version=None):
+
+def remove_proton(version=None) -> bool:
     """Uninstall existing proton installation"""
-    if not version.startswith("Proton-"):
-        version = "Proton-" + version
-    target = install_directory() + version
+    target = install_directory() + str(version)
     if os.path.exists(target):
         shutil.rmtree(target)
         return True
